# ----------------------------------- Tax --------------------------------------------------- #
## ---------------- Behavior Tax ---------------------- ##
from cpanlp.tax.behavior_tax import *
from cpanlp.tax.transaction_tax import *
## ---------------- Income Tax ---------------------- ##
from cpanlp.tax.income_tax import *
from cpanlp.tax.personal_income_tax import *
from cpanlp.tax.corporate_income_tax import *
## ---------------- Property Tax ---------------------- ##
from cpanlp.tax.property_tax import *
from cpanlp.tax.real_estate_tax import *
## ---------------- Tax ---------------------- ##
from cpanlp.tax.tax import *
## ---------------- Trunover Tax ---------------------- ##
from cpanlp.tax.turnover_tax import *
from cpanlp.tax.VAT import *
from cpanlp.tax.consumption_tax import *