from cpanlp.account.assets.asset import *
from cpanlp.account.assets.fixedasset import *
from cpanlp.account.assets.inventory import *
from cpanlp.account.assets.investmentproperty import *
## ---------------- IntangibleAsset ---------------------- ##
from cpanlp.account.assets.intangibleasset.intangibleasset import *
from cpanlp.account.assets.intangibleasset.landuseright import *
from cpanlp.account.assets.intangibleasset.goodwill import *
from cpanlp.account.assets.intangibleasset.intellectualproperty import *
from cpanlp.account.assets.intangibleasset.franchise import *
from cpanlp.account.assets.intangibleasset.patent import *
## ---------------- FinancialAsset ---------------------- ##
from cpanlp.account.assets.financialasset.financialasset import *
from cpanlp.account.assets.financialasset.bankdeposit import *
from cpanlp.account.assets.financialasset.stock import *
from cpanlp.account.assets.financialasset.receivables.accounts_receivables import *
from cpanlp.account.assets.financialasset.receivables.dividend_receivable import *
